window.Gleam.initSearch([{"doc":"staff_ai","title":"staff_ai","content":"# staff\n\n[![Package Version](https://img.shields.io/hexpm/v/staff_ai)](https://hex.pm/packages/staff_ai)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/staff_ai/)\n\n```sh\ngleam add staff_ai\n```\n```gleam\nimport staff_ai.{Agent, create_agent}\n\npub fn main() {\n  let agent: Agent =\n    create_agent(\n      &quot;John Doe&quot;,\n      &quot;AI researcher&quot;,\n      Some(\n        &quot;John is an AI researcher who is passionate about building AI agents that can accomplish tasks for people. He has a PhD in AI an has been working in the field for over 10 years. He is excited to be a part of the Staff-AI team.&quot;,\n      ),\n    )\n  io.debug(agent)\n}\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/staff_ai&gt;.\n\n## Development\n\n```sh\ngleam run   # Run the project\ngleam test  # Run the tests\ngleam shell # Run an Erlang shell\n```\n","url":"index.html"},{"doc":"staff_ai","title":"Agent","content":"pub type Agent {\n  Agent(\n    id: UUID,\n    name: String,\n    role: String,\n    context: Option(String),\n  )\n}\n Represents an AI worker in a staff system\n \n It represents the most simple unit of you staff who can be assigned to a task.\n Agent has a name, a list of skills and a list of tasks, which he is currently working on.\n\nAgent(\n  id: UUID,\n  name: String,\n  role: String,\n  context: Option(String),\n)\n\nid\n&lt;p&gt;Unique identifier of the agent&lt;/p&gt;\n\nname\n&lt;p&gt;Name of the agent, which is used to identify him in your system.\nIt can be a real name or a nickname, e.g. “Jane Doe” or “jane_doe”&lt;/p&gt;\n\nrole\n&lt;p&gt;Role of the agent, which is used to identify his skills and responsibilities in your system.\nIt can be a real role or a nickname, e.g. “Software Developer” or “dev”&lt;/p&gt;\n\ncontext\n&lt;p&gt;Adding a context to an agent is optional, but it can be useful to store additional information about the agent.\nIt can be used to store additional information about the agent as it will influence the way it reacts to tasks.\nE.g. “Jane Doe is a technical lead of the project X. She is responsible for the architecture and …”&lt;/p&gt;\n\nSynonyms:\nstaff_ai.Agent\nstaff_ai Agent","url":"staff_ai.html#Agent"},{"doc":"staff_ai","title":"Squad","content":"pub type Squad {\n  Squad(\n    id: UUID,\n    name: String,\n    objective: String,\n    agents: List(Agent),\n    tasks: List(Task),\n  )\n}\n Squad is a group of agents that can are working together on a specific Objective.\n \n It represents isolated groups of agents with diverse skills and responsibilities.\n The squad has a name, an objective and a list of agents, which are part of the squad.\n \nSquad(\n  id: UUID,\n  name: String,\n  objective: String,\n  agents: List(Agent),\n  tasks: List(Task),\n)\n\nid\n&lt;p&gt;Unique identifier of the squad&lt;/p&gt;\n\nname\n&lt;p&gt;Name of the squad, which is used to identify it in your system.\nIt can be a real name or a nickname, e.g. “Software Development Team” or “dev_team”&lt;/p&gt;\n\nobjective\n&lt;p&gt;Objective of the squad, which is used to identify the goal of the squad in your system.\nIt can be a real objective or a nickname, e.g. “Develop the new feature X” or “feature_x”\nThe objective should be as clear as possible to be sub-divided into granular tasks.&lt;/p&gt;\n\nagents\n&lt;p&gt;The list of agents that are part of the squad, this list can evolve over time.&lt;/p&gt;\n\ntasks\n&lt;p&gt;The list of tasks that are part of the squad, this list will evolve over time\nas tasks are created and completed.&lt;/p&gt;\n\nSynonyms:\nstaff_ai.Squad\nstaff_ai Squad","url":"staff_ai.html#Squad"},{"doc":"staff_ai","title":"Task","content":"pub type Task {\n  Task(\n    id: UUID,\n    title: String,\n    description: String,\n    status: TaskStatus,\n    assigned_agent: Option(UUID),\n    created_at: birl.Time,\n    updated_at: birl.Time,\n    completed_at: Option(birl.Time),\n    cancelled_at: Option(birl.Time),\n    failed_at: Option(birl.Time),\n  )\n}\n A task that can be performed by an agent\n \n It represents the most simple unit of work that an Agent can perform.\n The task can involve any input and output, but it is expected to be\n a small unit of work that can be performed in a short amount of time.\n \nTask(\n  id: UUID,\n  title: String,\n  description: String,\n  status: TaskStatus,\n  assigned_agent: Option(UUID),\n  created_at: birl.Time,\n  updated_at: birl.Time,\n  completed_at: Option(birl.Time),\n  cancelled_at: Option(birl.Time),\n  failed_at: Option(birl.Time),\n)\n\nid\n&lt;p&gt;The unique identifier of the task&lt;/p&gt;\n\ntitle\n&lt;p&gt;A meaningful title of the task&lt;/p&gt;\n\ndescription\n&lt;p&gt;A description of the task, must be detailed enough to be performed&lt;/p&gt;\n\nstatus\n&lt;p&gt;The status of the task&lt;/p&gt;\n\nassigned_agent\n&lt;p&gt;The unique identifier of the agent that has been assigned to perform the task&lt;/p&gt;\n\ncreated_at\n&lt;p&gt;The time when the task was created&lt;/p&gt;\n\nupdated_at\n&lt;p&gt;The time when the task was last updated&lt;/p&gt;\n\ncompleted_at\n&lt;p&gt;The time when the task was completed&lt;/p&gt;\n\ncancelled_at\n&lt;p&gt;The time when the task was cancelled&lt;/p&gt;\n\nfailed_at\n&lt;p&gt;The time when the task has failed&lt;/p&gt;\n\nSynonyms:\nstaff_ai.Task\nstaff_ai Task","url":"staff_ai.html#Task"},{"doc":"staff_ai","title":"TaskStatus","content":"pub type TaskStatus {\n  Ready\n  InProgress\n  Completed\n  Cancelled\n  Failed\n}\n The status of the task\n \nReady\n The task is ready to be performed\n\nInProgress\n The task is currently being performed\n\nCompleted\n The task has been completed\n\nCancelled\n The task has been cancelled\n\nFailed\n The task has failed\n\nSynonyms:\nstaff_ai.TaskStatus\nstaff_ai TaskStatus","url":"staff_ai.html#TaskStatus"},{"doc":"staff_ai","title":"UUID","content":"pub type UUID =\n  String\n Represents a unique identifier, which is a string in the UUID format.\n \n\nSynonyms:\nstaff_ai.UUID\nstaff_ai UUID","url":"staff_ai.html#UUID"},{"doc":"staff_ai","title":"create_agent","content":"pub fn create_agent(\n  name: String,\n  role: String,\n  context: Option(String),\n) -&gt; Agent\n Creates a new agent with the given parameters.\n \nSynonyms:\nstaff_ai.create_agent\nstaff_ai create_agent","url":"staff_ai.html#create_agent"},{"doc":"staff_ai","title":"create_squad","content":"pub fn create_squad(\n  name: String,\n  objective: String,\n  agents: List(Agent),\n  tasks: List(Task),\n) -&gt; Squad\n Creates a new squad with the given parameters.\n \nSynonyms:\nstaff_ai.create_squad\nstaff_ai create_squad","url":"staff_ai.html#create_squad"},{"doc":"staff_ai","title":"create_task","content":"pub fn create_task(\n  title: String,\n  description: String,\n  assigned_agent: Option(String),\n) -&gt; Task\n Create a new task\n \nSynonyms:\nstaff_ai.create_task\nstaff_ai create_task","url":"staff_ai.html#create_task"},{"doc":"staff_ai","title":"staff_ai","content":"","url":"staff_ai.html"}]);